/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.engine.helloworld;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.objectweb.petals.component.framework.util.StringHelper;
import org.objectweb.petals.jbi.descriptor.util.XMLUtil;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * The Helloworld service implementation
 *
 * @author eBM WebSourcing
 *
 */
public class HelloworldImpl implements Helloworld {

	public static final String HELLOWORLD_CONTEXT = "helloworldContext";

	public static final String HELLOWORLD_JNDI_ENTRY = "helloworldEntry";

	private Logger logger; // NOPMD

	/**
	 * Creates a new instance of HelloworldImpl
	 *
	 * @param logger
	 */
	public HelloworldImpl(Logger logger) {
		super();
		this.logger = logger;
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.objectweb.petals.engine.helloworld.Helloworld#printMessage(java.lang.String)
	 */
	public void printMessage(final String message) {
		if (StringHelper.isNullOrEmpty(message)) {
			logger.log(Level.INFO, "hello.printNothing");
		} else {
			logger.log(Level.INFO, "hello.received: " + message);
		}
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.objectweb.petals.engine.helloworld.Helloworld#sayHello(java.lang.String)
	 */
	public String sayHello(final String message) {
		StringBuffer response = new StringBuffer();
		response
				.append("<sayHelloResponse xmlns=\"http://org.objectweb.petals/\">");
		response.append("<sayHelloReturn>");
		response.append("you told me : ");

		if (StringHelper.isNullOrEmpty(message)) {
			logger.log(Level.INFO, "hello.printNothing");
			response.append("nothing");
		} else {
			logger.log(Level.INFO, "hello.received", new String[] { message });
			response.append(deleteRootTags(message));
		}
		response.append("</sayHelloReturn></sayHelloResponse>");

		return response.toString();
	}

	/**
	 * go deep in the xml document, and return the text node
	 *
	 * @param body
	 *            xml document
	 * @return the deepest text node, or body if no textnode found
	 */
	private String deleteRootTags(String body) {
		String result = body;
		Document domContent = XMLUtil.createDocumentFromString(body);

		// Retrieve document root element
		Node element = domContent.getFirstChild();
		// remove all elements that exist
		while (XMLUtil.getFirstChild(element) != null) {
			element = XMLUtil.getFirstChild(element);
		}
		if (element != null) {
			result = XMLUtil.getTextContent(element);
		}
		return result;
	}
}
